@@ -30,12 +30,16 @@ namespace libsemigroups {
   void init_cong(py::module&);
   void init_forest(py::module&);
   void init_fpsemi(py::module&);
+  void init_fpsemi_examples(py::module&);
   void init_froidure_pin(py::module&);
+  void init_kambites(py::module&);
+  void init_konieczny(py::module&);
   void init_knuth_bendix(py::module&);
   void init_matrix(py::module&);
   void init_pbr(py::module&);
   void init_present(py::module&);
   void init_sims1(py::module&);
+  void init_stephen(py::module&);
   void init_todd_coxeter(py::module&);
   void init_transf(py::module&);
   void init_words(py::module&);
